@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -48,7 +48,7 @@
 NotesAgentAlarmDialog::NotesAgentAlarmDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Alarm"));
+    setWindowTitle(i18nc("@title:window", "Alarm"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("knotes")));
     setAttribute(Qt::WA_DeleteOnClose);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
